@@ -93,7 +93,7 @@ use strict;
 use warnings;
 use v5.10;
 
-our $VERSION = '0.16';
+our $VERSION = '0.17';
 
 use List::Util;
 use JSON::XS;
@@ -116,6 +116,21 @@ sub _is_subdir {
     return ($c =~ m[^\Q$p\E]) ? 1 : 0;
 }
 
+my $is_test = 0;
+sub _testing {
+  my($class, $new) = @_;
+  $is_test = $new if defined $new;
+  $is_test;
+}
+
+our $class_suffix = {};
+sub _uncache {
+    my($class, $name) = @_;
+    delete $Clustericious::Config::Singletons{$name};
+    $class_suffix->{$name} //= 1;
+    $class_suffix->{$name}++;
+}
+
 =head2 new
 
 Create a new Clustericious::Config object.  See the SYPNOSIS for
@@ -130,8 +145,11 @@ sub new {
     ($arg = caller) =~ s/:.*$// unless $arg; # Determine from caller's class
     return $Singletons{$arg} if exists($Singletons{$arg});
 
+    
     my $we_are_testing_this_module = 0;
-    if ($ENV{HARNESS_ACTIVE} and -d '_build' && -e '_build/build_params' && Module::Build->can("current")) {
+    if(__PACKAGE__->_testing) {
+        $we_are_testing_this_module = 0;
+    } elsif ($ENV{HARNESS_ACTIVE} and -d '_build' && -e '_build/build_params' && Module::Build->can("current")) {
         my $mb = Module::Build->current;
         $we_are_testing_this_module = $mb && $mb->module_name eq $arg;
     }
@@ -172,7 +190,7 @@ sub new {
 
         @conf_dirs = $ENV{CLUSTERICIOUS_CONF_DIR} if defined( $ENV{CLUSTERICIOUS_CONF_DIR} );
 
-        push @conf_dirs, ( File::HomeDir->my_home . "/etc", "/util/etc", "/etc" ) unless $we_are_testing_this_module;
+        push @conf_dirs, ( File::HomeDir->my_home . "/etc", "/util/etc", "/etc" ) unless $we_are_testing_this_module || __PACKAGE__->_testing;
         my $conf_file = "$arg.conf";
         my ($dir) = List::Util::first { -e "$_/$conf_file" } @conf_dirs;
         if ($dir) {
@@ -206,6 +224,7 @@ sub new {
             $arg =~ tr/a-zA-Z0-9//cd;
         }
         $class = join '::', $class, $arg;
+        $class .= $class_suffix->{$arg} if $class_suffix->{$arg};
         my $dome = '@'."$class"."::ISA = ('".__PACKAGE__. "')";
         eval $dome;
         die "error setting ISA : $@" if $@;
